@@ -140,9 +140,9 @@ class Gdk::MiraclePainter < Gtk::Object
         textselector_release(*main_pos_to_index_forclick(x, y)[1..2]) end end end
 
   # 座標 ( _x_ , _y_ ) にクリックイベントを発生させる
-  def clicked(x, y, e)
-    signal_emit(:click, e, x, y)
-    case e.button
+  def clicked(x, y, event)
+    signal_emit(:click, event, x, y)
+    case event.button
     when 1
       iob_clicked
       if not textselector_range
@@ -220,13 +220,13 @@ class Gdk::MiraclePainter < Gtk::Object
     x -= pos.main_text.x
     y -= pos.main_text.y
     inside, byte, trailing = *main_message.xy_to_index(x * Pango::SCALE, y * Pango::SCALE)
-    message.to_s.get_index_from_byte(byte) if inside end
+    main_message.text.get_index_from_byte(byte) if inside end
 
   def main_pos_to_index_forclick(x, y)
     x -= pos.main_text.x
     y -= pos.main_text.y
     result = main_message.xy_to_index(x * Pango::SCALE, y * Pango::SCALE)
-    result[1] = message.to_s.get_index_from_byte(result[1])
+    result[1] = main_message.text.get_index_from_byte(result[1])
     return *result end
 
   def signal_do_modified()
@@ -368,12 +368,15 @@ class Gdk::MiraclePainter < Gtk::Object
     render_parts context end
 
   def render_background(context)
-    context.save{
+    context.save do
       context.set_source_rgb(*get_backgroundcolor)
       context.rectangle(0,0,width,height)
       context.fill
-    }
-  end
+      if Gtk.konami
+        context.save do
+          context.translate(width - 48, height - 54)
+          context.set_source_pixbuf(Gtk.konami_image)
+          context.paint end end end end
 
   def render_main_icon(context)
     context.save{
@@ -381,7 +384,8 @@ class Gdk::MiraclePainter < Gtk::Object
       context.set_source_pixbuf(main_icon)
       context.paint
     }
-    render_icon_over_button(context)
+    if not (message.to_message.system?)
+      render_icon_over_button(context) end
   end
 
   def render_main_text(context)
